#!/usr/bin/perl
#=======================================================================
# FileName : cmd_GetAileLogFiles.pl
# Summary  : Aileunログファイル取得ベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/24 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

exit $ret;

#=======================================================================
# FuncName : main
# Summary  : Aileunログファイル取得メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/24 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile   = $_[0];
    my $resFile   = $_[1];
    my $requestData = "";
    my $json = "";
    my %responseData = ();
    my %conf      = ();
    my $logLevel = "";
    my $logmsg = "";
    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";
    $responseData{ComConst::JSON_KEY_DAT} = ();
    my $key = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエスト読み込み
    if($rc == ComConst::STS_OK){
        $requestData = CmdComFunc::readRequestFile($reqFile);
    }

    # 入力チェック
    if($rc == ComConst::STS_OK){
         # 入力はないので処理なし
    }

    # データ作成
    if($rc == ComConst::STS_OK){
        # Aileunのログファイルを取得
        my $exec_cmd = sprintf(ComConst::CMPRESS_AILEUN_LOG_CMD, ComConst::DATA_DIR_PATH);
        
        my $logFileName = `$exec_cmd`;
        if($logFileName =~ /^aile_log_.*$/){
            $responseData{ComConst::JSON_KEY_DAT}{RedirectUrl} = sprintf("data/%s", $logFileName);
        }else{
            $responseData{ComConst::JSON_KEY_DAT}{RedirectUrl} = "";
            $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
            $responseData{ComConst::JSON_KEY_MSG} = $messages{CM003E001};
        }
    }

    # レスポンスファイル出力
    $rc = CmdComFunc::writeResponseFile($resFile, \%responseData);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}
