#!/usr/bin/perl
package ComConst;
#=======================================================================
# FileName : ComConst.pm
# Summary  : 共通定義
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/02/23 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;

use constant EXEC_SYSTEM => '1';

use constant REQUEST_PATH => '../tmp';
use constant RESPONSE_PATH => '../tmp';
use constant BASE_CMD_PATH => '../bin';
use constant DATA_DIR_PATH => '../data';
use constant CONF_PATH => '../conf';
use constant MSG_PATH => '../conf/Locale/';

use constant JSON_KEY_STS => 'status';
use constant JSON_KEY_MSG => 'message';
use constant JSON_KEY_DAT => 'data';

use constant RETRY_CNT => 3;
use constant SLEEP_TIME => 1;

use constant ENCODINGS => 'utf8';

use constant NON_SETTING => "-";
use constant DEFAULT_DATE_FORMAT => '%04d%02d%02d%02d%02d%02d';

##### ステータス #####
use constant STS_OK =>  0;
use constant STS_NG => -1;
use constant STS_ERR_SES => -11;
use constant STS_ERR_FILE => -2;

##### Aileun #####
use constant AILEUN_MODEL_4 => 4;
use constant AILEUN_MODEL_5 => 5;
use constant AILEUN_VERSION_FILE => '/opt/aile/version.txt';
use constant SEAMLESS_VIEWER_CONFIG => '/opt/aile/config/ViewerSeamlessConfig.conf';
use constant GET_AILEUN_VERSION_CMD => 'head -n 1 %s';
use constant GET_AILEUN_MODELNO_CMD => 'head -n 1 %s | awk -F. \'{print $1\'}';
use constant AILEUN_PRDCTNO_FILE => '/tmp/prdx2wr';
use constant GET_AILEUN_PRDCTNO_CMD => 'head -n 1 %s';
use constant SPECIAL_CONFIG_N => "";
use constant CMPRESS_AILEUN_CONFIG_CMD => '../bin/cmpressAileunConfigFiles.sh %s';
use constant AILEUN4_CONFIG_ZIPFILE => 'aileun_4.zip';
use constant AILEUN5_CONFIG_ZIPFILE => 'aileun_5.zip';
use constant AILE_CONFIG_DIR => '/opt/aile/config/';
use constant AILEUN_CONFIG_CHK_CMD => '../bin/validateAileunConfigFile.sh %s';
use constant CONFIG_CHK_ST_ARG_ERR => 256;
use constant CONFIG_CHK_ST_UNZIP_ERR => 512;
use constant CONFIG_CHK_ST_REQ_ERR => 768;
use constant AILEUN_CONFIG_LOAD_CMD => '../bin/uncmpressAileunConfigFile.sh';
use constant AILEUN_PKG_FILE_NAME => 'aile.tar.gz';
use constant AILEUN_PKG_CHK_ST_ARG_ERR => 256;
use constant AILEUN_PKG_CHK_ST_VALIDATE_ERR => 1280;
use constant AILEUN_PKG_CHK_CMD => '../bin/validateAileunUpdatePackage.sh %s';
use constant AILEUN_PKG_MV_CMD => '../bin/mvAileunUpdatePackage.sh';
use constant CMPRESS_AILEUN_LOG_CMD => '../bin/cmpressAileunBackuplog.sh %s';
use constant NORMAL_CHANNEL36 => '36';
use constant NORMAL_CHANNEL16 => '16';
use constant NORMAL_CHANNEL12 => '12';
use constant NORMAL_CHANNEL9 => '9';
use constant NORMAL_CHANNEL8 => '8';
use constant NORMAL_CHANNEL4 => '4';
use constant CHANNEL16_WEB_RC_CONFIG => '../conf/16ChannelWebRemoteContolerConfig.conf';
use constant CHANNEL12_WEB_RC_CONFIG => '../conf/12ChannelWebRemoteContolerConfig.conf';
use constant CHANNEL9_WEB_RC_CONFIG => '../conf/9ChannelWebRemoteContolerConfig.conf';
use constant CHANNEL8_WEB_RC_CONFIG => '../conf/8ChannelWebRemoteContolerConfig.conf';
use constant CHANNEL4_WEB_RC_CONFIG => '../conf/4ChannelWebRemoteContolerConfig.conf';
use constant CHANNEL36_WEB_RC_SEAMLESS_CONFIG => '../conf/36ChannelWebRemoteContolerConfigSeamless.conf';
use constant CHANNEL16_WEB_RC_SEAMLESS_CONFIG => '../conf/16ChannelWebRemoteContolerConfigSeamless.conf';
use constant CHANNEL12_WEB_RC_SEAMLESS_CONFIG => '../conf/12ChannelWebRemoteContolerConfigSeamless.conf';
use constant CHANNEL9_WEB_RC_SEAMLESS_CONFIG => '../conf/9ChannelWebRemoteContolerConfigSeamless.conf';
use constant CHANNEL8_WEB_RC_SEAMLESS_CONFIG => '../conf/8ChannelWebRemoteContolerConfigSeamless.conf';
use constant CHANNEL4_WEB_RC_SEAMLESS_CONFIG => '../conf/4ChannelWebRemoteContolerConfigSeamless.conf';
use constant AILEUN_SEND_MSG => 'id:%s,action:%s,view_no:%s,data:%s,auth:%s';
use constant FORBIDDEN_BASIC_USERS => '../conf/forbiddenUserNameList.json';
use constant FUNC_LIMITED_FILE => '/tmp/.LimitedWebFunc';

use constant HTTP_ALARM_SOCK_PATH => '/tmp/http_alarm.sock';
use constant HTTP_ALARM_DATATEMPLATE => '{"ViewCH":"$<ViewCH>"}';
our $HTTP_REQUEST_KEYS = {
	"ViewCH" => {"range"=>[1, 36]}
};

use constant TYPEKEYSYS => "sys";
use constant TYPEKEYINQ => "inq";
use constant SENDKEYNUM => "Num";
use constant SENDKEYCUR => "Cursor";
use constant SENDKEYFOCUS => "Focus";
use constant SENDKEYZOOM => "Zoom";
use constant SENDKEYPANTILT => "PanTilt";
use constant SENDKEYPOWER => "Power";

use constant SYSKEYNUMDATATEMPLATE => '{"btnId":"%s", "reqType":"key%d", "targetView":-999, "reqData":""}';
use constant SYSKEYCURDATATEMPLATE => '{"btnId":"%s", "reqType":"keyCur%s", "targetView":-999, "reqData":""}';
use constant SYSKEYOTHERDATATEMPLATE => '{"btnId":"%s", "reqType":"key%s", "targetView":-999, "reqData":""}';
use constant INQKEYDATATEMPLATE => '{"btnId":"%s", "reqType":"%s", "targetView":-999, "reqData":"", "auth":"%s"}';

# WEB-AILEUN間通信リクエストチェック
our $RequiredRequestParams = {
    "sys" => {
        "Num"    => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isNumValidValue", "defineValueKeyName"=>"", "template"=>SYSKEYNUMDATATEMPLATE},
        "Camnum" => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isCamNumValidValue", "defineValueKeyName"=>"", "template"=>SYSKEYNUMDATATEMPLATE},
        "Cursor" => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"%04b", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"CursorKey", "template"=>SYSKEYCURDATATEMPLATE},
        "Left"   => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Enter"  => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Menu"   => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Aster"  => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Clear"  => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Movie"  => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"%04b", "validate_data_func"=>"", "defineValueKeyName"=>"PlayOperateKey", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Preset" => {"required"=>["type", "sendkey"], "value_param_key"=>"sendkey", "format"=>"", "validate_data_func"=>"", "defineValueKeyName"=>"", "template"=>SYSKEYOTHERDATATEMPLATE},
        "Split" => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"%04b", "validate_data_func"=>"", "defineValueKeyName"=>"ViewSplitKey", "template"=>SYSKEYOTHERDATATEMPLATE},
     },
    "inq" => {
        "Focus"   => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"FocusKey", "template"=>INQKEYDATATEMPLATE},
        "Zoom"    => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"ZoomKey", "template"=>INQKEYDATATEMPLATE},
        "Pantilt" => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"%04b", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"PanTiltKey", "template"=>INQKEYDATATEMPLATE},
        "Power"   => {"required"=>["type", "sendkey", "value"], "value_param_key"=>"value", "format"=>"", "validate_data_func"=>"isDefinedValue", "defineValueKeyName"=>"PowerKey", "template"=>INQKEYDATATEMPLATE},
    }
};

our $HwType2CamNum = {
    "YS1504-R"   => 4,
    "YS1504-M"   => 4,
    "YS2008-R"   => 8,
    "YS2008-AR"  => 8,
    "YS2008-A"   => 8,
    "YS2008-AM"  => 8,
    "YS2008-AMR" => 8,
    "YS2016-AM"  => 16,
    "YS3009-AM"  => 9,
    "YS3009-AR"  => 9,
    "YS3012-A"   => 12,
    "YS3012-AM"  => 12,
    "YS3016-A"   => 16,
    "YS3016-AM"  => 16,
    "YS2104-A"   => 8,
    "YS2104-AM"  => 4,
    "YS2104-AR"  => 4,
    "YS2108-A"   => 8,
    "YS2108-AM"  => 8,
    "YS2108-AR"  => 8,
    "YS2108-AMR" => 8,
    "YS2212-A"   => 12,
    "YS2212-AM"  => 12,
    "YS2216-A"   => 16,
    "YS2216-AM"  => 16,
    "YS2304-AR"  => 4,
    "YS2308-A"   => 8,
    "YS2308-AM"  => 8,
    "YS2308-AR"  => 8,
    "YS2308-AMR" => 8,
    "YS2316-A"   => 16,
    "YS2316-AM"  => 16,
    "YS2336-A"   => 36,
    "YS2336-AM"  => 36,
};

our $Product2HwType = {
    "DS67U"      => "YS2008-AR",
    "DS68U"      => "YS2008-AR",
    "YS-2104A"   => "YS2104-A",
    "YS-2104AM"  => "YS2104-AM",
    "YS-2104AR"  => "YS2104-AR",
    "YS-2108A"   => "YS2108-A",
    "YS-2108AM"  => "YS2108-AM",
    "YS-2108AR"  => "YS2108-AR",
    "YS-2108AMR" => "YS2108-AMR",
    "YS-2212A"   => "YS2212-A",
    "YS-2212AM"  => "YS2212-AM",
    "YS-2216A"   => "YS2216-A",
    "YS-2216AM"  => "YS2216-AM",
    "YS-2304AR"  => "YS2304-AR",
    "YS-2308A"   => "YS2308-A",
    "YS-2308AM"  => "YS2308-AM",
    "YS-2308AR"  => "YS2308-AR",
    "YS-2308AMR" => "YS2308-AMR",
    "YS-2316A"   => "YS2316-A",
    "YS-2316AM"  => "YS2316-AM",
    "YS-2336A"   => "YS2336-A",
    "YS-2336AM"  => "YS2336-AM",
};


1;
